package com.ruoyi.project.training.bccnew.controller;

import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.framework.aspectj.lang.annotation.Log;
import com.ruoyi.framework.aspectj.lang.enums.BusinessType;
import com.ruoyi.framework.web.controller.BaseController;
import com.ruoyi.framework.web.domain.AjaxResult;
import com.ruoyi.framework.web.page.TableDataInfo;
import com.ruoyi.project.system.domain.SysUser;
import com.ruoyi.project.system.service.ISysUserService;
import com.ruoyi.project.training.bccnew.domain.TTsFtplan;
import com.ruoyi.project.training.bccnew.domain.TTsNew;
import com.ruoyi.project.training.bccnew.service.ITTsFtplanService;
import com.ruoyi.project.training.bccnew.service.ITTsNewService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 芳烃培训Controller
 *
 * @author ssy
 * @date 2024-06-13
 */
@RestController
@RequestMapping("/bccnew/ftplandsdt")
public class TTsFtplanController extends BaseController {
    @Autowired
    private ITTsFtplanService tTsFtplanService;
    @Autowired
    private ITTsNewService tTsNewService;
    @Autowired
    private ISysUserService sysUserService;

    /**
     * 查询芳烃培训列表
     */
    @GetMapping("/list")
    public TableDataInfo list(TTsFtplan tTsFtplan) {
        startPage();
        List<TTsFtplan> list = tTsFtplanService.selectTTsFtplanList(tTsFtplan);
        return getDataTable(list);
    }

    /**
     * 导出芳烃培训列表
     */
    @Log(title = "芳烃培训", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(TTsFtplan tTsFtplan) {
        List<TTsFtplan> list = tTsFtplanService.selectTTsFtplanList(tTsFtplan);
        ExcelUtil<TTsFtplan> util = new ExcelUtil<TTsFtplan>(TTsFtplan.class);
        return util.exportExcel(list, "ftplandsdt");
    }

    /**
     * 获取芳烃培训详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return AjaxResult.success(tTsFtplanService.selectTTsFtplanById(id));
    }

    /**
     * 新增芳烃培训
     */
    @Log(title = "芳烃培训", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TTsFtplan tTsFtplan) {
        return toAjax(tTsFtplanService.insertTTsFtplan(tTsFtplan));
    }

    @Log(title = "芳烃培训", businessType = BusinessType.UPDATE)
    @PutMapping("/updateFtLearnTime")
    public AjaxResult updateFtLearnTime(@RequestBody TTsFtplan tTsFtplan) {
        Long userId = getUserId();
        TTsNew tTsNew = tTsNewService.selectTTsNewById(tTsFtplan.getNewId());
        SysUser sysUser = sysUserService.selectUserByStaffId(tTsNew.getStaffId());
        if (userId.equals(sysUser.getUserId())) {
            TTsFtplan plan = new TTsFtplan();
            plan.setId(tTsFtplan.getId());
            long timer = tTsFtplan.getTimer() == null ? 0 : tTsFtplan.getTimer();
            plan.setTimer(timer + 1);
            TTsFtplan need = tTsFtplanService.selectTTsFtplanById(tTsFtplan.getId());
            if (need.getTimerNeed() != null && need.getTimerNeed().equals(timer + 1)) {
                plan.setPlanStatus(2L);
            }
            return toAjax(tTsFtplanService.updateTTsFtplan(plan));
        }
        return AjaxResult.error("当前登录用户非学习用户!");
    }

    /**
     * 修改芳烃培训
     */
    @Log(title = "芳烃培训", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TTsFtplan tTsFtplan) {
        return toAjax(tTsFtplanService.updateTTsFtplan(tTsFtplan));
    }

    /**
     * 删除芳烃培训
     */
    @Log(title = "芳烃培训", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(tTsFtplanService.deleteTTsFtplanByIds(ids));
    }
}
