package com.ruoyi.project.training.bccnew.controller;

import java.util.List;

import com.ruoyi.project.system.domain.SysUser;
import com.ruoyi.project.system.service.ISysUserService;
import com.ruoyi.project.training.bccnew.domain.TTsNew;
import com.ruoyi.project.training.bccnew.service.ITTsNewService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.framework.aspectj.lang.annotation.Log;
import com.ruoyi.framework.aspectj.lang.enums.BusinessType;
import com.ruoyi.project.training.bccnew.domain.TTsLjplan;
import com.ruoyi.project.training.bccnew.service.ITTsLjplanService;
import com.ruoyi.framework.web.controller.BaseController;
import com.ruoyi.framework.web.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.framework.web.page.TableDataInfo;

/**
 * 裂解培训Controller
 *
 * @author ssy
 * @date 2024-06-13
 */
@RestController
@RequestMapping("/bccnew/ljplandsdt")
public class TTsLjplanController extends BaseController
{
    @Autowired
    private ITTsLjplanService tTsLjplanService;
    @Autowired
    private ITTsNewService tTsNewService;
    @Autowired
    private ISysUserService sysUserService;

    /**
     * 查询裂解培训列表
     */
    @GetMapping("/list")
    public TableDataInfo list(TTsLjplan tTsLjplan)
    {
        startPage();
        List<TTsLjplan> list = tTsLjplanService.selectTTsLjplanList(tTsLjplan);
        return getDataTable(list);
    }

    /**
     * 导出裂解培训列表
     */
    @Log(title = "裂解培训", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(TTsLjplan tTsLjplan)
    {
        List<TTsLjplan> list = tTsLjplanService.selectTTsLjplanList(tTsLjplan);
        ExcelUtil<TTsLjplan> util = new ExcelUtil<TTsLjplan>(TTsLjplan.class);
        return util.exportExcel(list, "ljplandsdt");
    }

    /**
     * 获取裂解培训详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(tTsLjplanService.selectTTsLjplanById(id));
    }

    /**
     * 新增裂解培训
     */
    @Log(title = "裂解培训", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TTsLjplan tTsLjplan)
    {
        return toAjax(tTsLjplanService.insertTTsLjplan(tTsLjplan));
    }

    /**
     * 修改裂解培训
     */
    @Log(title = "裂解培训", businessType = BusinessType.UPDATE)
    @PutMapping("/updateLjLearnTime")
    public AjaxResult updateLjLearnTime(@RequestBody TTsLjplan tTsLjplan){
        Long userId = getUserId();
        TTsNew tTsNew = tTsNewService.selectTTsNewById(tTsLjplan.getNewId());
        SysUser sysUser = sysUserService.selectUserByStaffId(tTsNew.getStaffId());
        if(userId.equals(sysUser.getUserId())){
            TTsLjplan plan = new TTsLjplan();
            plan.setId(tTsLjplan.getId());
            long timer = tTsLjplan.getTimer()==null?0:tTsLjplan.getTimer();
            plan.setTimer(timer+1);
            TTsLjplan need = tTsLjplanService.selectTTsLjplanById(tTsLjplan.getId());
            if (need.getTimerNeed()!=null&&need.getTimerNeed().equals(timer+1)){
                plan.setPlanStatus(2L);
            }
            return toAjax(tTsLjplanService.updateTTsLjplan(plan));
        }
        return AjaxResult.error("当前登录用户非学习用户!");
    }


    /**
     * 修改裂解培训
     */
    @Log(title = "裂解培训", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TTsLjplan tTsLjplan)
    {
        return toAjax(tTsLjplanService.updateTTsLjplan(tTsLjplan));
    }

    /**
     * 删除裂解培训
     */
    @Log(title = "裂解培训", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tTsLjplanService.deleteTTsLjplanByIds(ids));
    }
}
