package com.ruoyi.project.training.bccnew.controller;

import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.framework.aspectj.lang.annotation.Log;
import com.ruoyi.framework.aspectj.lang.enums.BusinessType;
import com.ruoyi.framework.web.controller.BaseController;
import com.ruoyi.framework.web.domain.AjaxResult;
import com.ruoyi.framework.web.page.TableDataInfo;
import com.ruoyi.project.system.domain.SysUser;
import com.ruoyi.project.system.service.ISysUserService;
import com.ruoyi.project.training.bccnew.domain.TTsNew;
import com.ruoyi.project.training.bccnew.domain.TTsYsplan;
import com.ruoyi.project.training.bccnew.service.ITTsNewService;
import com.ruoyi.project.training.bccnew.service.ITTsYsplanService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 转岗培训Controller
 *
 * @author ssy
 * @date 2024-06-13
 */
@RestController
@RequestMapping("/bccnew/ysplandsdt")
public class TTsYsplanController extends BaseController {
    @Autowired
    private ITTsYsplanService tTsYsplanService;
    @Autowired
    private ITTsNewService tTsNewService;
    @Autowired
    private ISysUserService sysUserService;

    /**
     * 查询转岗培训列表
     */
    @GetMapping("/list")
    public TableDataInfo list(TTsYsplan tTsYsplan) {
        startPage();
        List<TTsYsplan> list = tTsYsplanService.selectTTsYsplanList(tTsYsplan);
        return getDataTable(list);
    }

    /**
     * 导出转岗培训列表
     */
    @Log(title = "转岗培训", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(TTsYsplan tTsYsplan) {
        List<TTsYsplan> list = tTsYsplanService.selectTTsYsplanList(tTsYsplan);
        ExcelUtil<TTsYsplan> util = new ExcelUtil<TTsYsplan>(TTsYsplan.class);
        return util.exportExcel(list, "ysplandsdt");
    }

    /**
     * 获取转岗培训详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return AjaxResult.success(tTsYsplanService.selectTTsYsplanById(id));
    }

    /**
     * 新增转岗培训
     */
    @Log(title = "转岗培训", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TTsYsplan tTsYsplan) {
        return toAjax(tTsYsplanService.insertTTsYsplan(tTsYsplan));
    }


    @Log(title = "压缩培训", businessType = BusinessType.UPDATE)
    @PutMapping("/updateYsLearnTime")
    public AjaxResult updateYsLearnTime(@RequestBody TTsYsplan tTsYsplan) {
        Long userId = getUserId();
        TTsNew tTsNew = tTsNewService.selectTTsNewById(tTsYsplan.getNewId());
        SysUser sysUser = sysUserService.selectUserByStaffId(tTsNew.getStaffId());
        if (userId.equals(sysUser.getUserId())) {
            TTsYsplan plan = new TTsYsplan();
            plan.setId(tTsYsplan.getId());
            long timer = tTsYsplan.getTimer() == null ? 0 : tTsYsplan.getTimer();
            plan.setTimer(timer + 1);
            TTsYsplan need = tTsYsplanService.selectTTsYsplanById(tTsYsplan.getId());
            if (need.getTimerNeed() != null && need.getTimerNeed().equals(timer + 1)) {
                plan.setPlanStatus(2L);
            }
            return toAjax(tTsYsplanService.updateTTsYsplan(plan));
        }
        return AjaxResult.error("当前登录用户非学习用户!");
    }

    /**
     * 修改转岗培训
     */
    @Log(title = "转岗培训", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TTsYsplan tTsYsplan) {
        return toAjax(tTsYsplanService.updateTTsYsplan(tTsYsplan));
    }

    /**
     * 删除转岗培训
     */
    @Log(title = "转岗培训", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(tTsYsplanService.deleteTTsYsplanByIds(ids));
    }
}
